@@ -31,7 +31,7 @@
 #include "cursortheme/cursortheme.h"
 
 const int MIN_UID = 1000;
-const int MAX_UID = 65000;
+const int MAX_UID = 60000;
 
 AdvanceConfig::AdvanceConfig(const KSharedConfigPtr &config, QWidget *parent) :
     QWidget(parent),
@@ -118,24 +118,24 @@ QVariantMap AdvanceConfig::save()
     if (cursorIndex.isValid()) {
         const CursorTheme *cursorTheme = proxyCursorModel->theme(cursorIndex);
         if (cursorTheme)
-            args["sddm.conf/Theme/CursorTheme"] = cursorTheme->name();
+            args[QStringLiteral("sddm.conf/Theme/CursorTheme")] = cursorTheme->name();
     }
 
-    args["sddm.conf/Autologin/User"] = ( configUi->autoLogin->isChecked() ) ? configUi->userList->currentText() : "";
-    args["sddm.conf/Autologin/Session"] = ( configUi->autoLogin->isChecked() ) ? configUi->sessionList->currentData() : "";
+    args[QStringLiteral("sddm.conf/Autologin/User")] = ( configUi->autoLogin->isChecked() ) ? configUi->userList->currentText() : QString();
+    args[QStringLiteral("sddm.conf/Autologin/Session")] = ( configUi->autoLogin->isChecked() ) ? configUi->sessionList->currentData() : QString();
 
-    args["sddm.conf/Autologin/Relogin"] = configUi->reloginAfterQuit->isChecked();
+    args[QStringLiteral("sddm.conf/Autologin/Relogin")] = configUi->reloginAfterQuit->isChecked();
     //TODO session
 
     int minUid = configUi->minimumUid->text().toInt();
     int maxUid = configUi->maximumUid->text().toInt();
     if (isUidRangeValid(minUid, maxUid)) {
-        args["sddm.conf/Users/MinimumUid"] = configUi->minimumUid->text();
-        args["sddm.conf/Users/MaximumUid"] = configUi->maximumUid->text();
+        args[QStringLiteral("sddm.conf/Users/MinimumUid")] = configUi->minimumUid->text();
+        args[QStringLiteral("sddm.conf/Users/MaximumUid")] = configUi->maximumUid->text();
     }
 
-    args["sddm.conf/General/HaltCommand"] = configUi->haltCommand->url().toLocalFile();
-    args["sddm.conf/General/RebootCommand"] = configUi->rebootCommand->url().toLocalFile();
+    args[QStringLiteral("sddm.conf/General/HaltCommand")] = configUi->haltCommand->url().toLocalFile();
+    args[QStringLiteral("sddm.conf/General/RebootCommand")] = configUi->rebootCommand->url().toLocalFile();
 
     return args;
 }
