@@ -90,10 +90,10 @@ void ThemesModel::populate()
         endResetModel();
     }
 
-    QString themesBaseDir = KSharedConfig::openConfig(SDDM_CONFIG_FILE, KConfig::SimpleConfig)->group("Theme").readEntry("ThemeDir");
+    QString themesBaseDir = KSharedConfig::openConfig(QString::fromLatin1(SDDM_CONFIG_FILE), KConfig::SimpleConfig)->group("Theme").readEntry("ThemeDir");
 
     if (themesBaseDir.isEmpty()) {
-        themesBaseDir = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "sddm/themes", QStandardPaths::LocateDirectory);
+        themesBaseDir = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sddm/themes"), QStandardPaths::LocateDirectory);
     }
 
     QDir dir(themesBaseDir);
@@ -103,9 +103,9 @@ void ThemesModel::populate()
     }
 
     foreach (const QString &theme, dir.entryList(QDir::AllDirs | QDir::Readable)) {
-        QString path = themesBaseDir + '/' + theme;
+        QString path = themesBaseDir + QLatin1Char('/') + theme;
 
-        if (QFile::exists(path + "/metadata.desktop" )) {
+        if (QFile::exists(path + QStringLiteral("/metadata.desktop") )) {
             add(theme, path);
         }
     }
